@@ -473,7 +473,7 @@ def main(argv: Optional[List[str]]=None) -> int:
             # On Windows, parent process is aws2-wrap.exe, in unix it's the shell
             export_credentials(access_key, secret_access_key, session_token, profile)
         elif args.generatestdout:
-            print(f"profile {args.outprofile}")
+            print(f"[profile {args.outprofile}]")
             print("aws_access_key_id =", access_key)
             print("aws_secret_access_key =", secret_access_key)
             print("aws_session_token =", session_token)
